import _extends from "@babel/runtime/helpers/extends";

/** @jsx jsx */
import React, { forwardRef, memo, useMemo } from 'react';
import { jsx } from '@emotion/core';
import { useGlobalTheme } from '@atlaskit/theme/components';
import CodeBidiWarning from './bidi-warning';
import codeBidiWarningDecorator from './bidi-warning/bidi-warning-decorator';
import { getCodeStyles } from './internal/theme/styles';
const Code = /*#__PURE__*/memo( /*#__PURE__*/forwardRef(function Code({
  testId,
  ...props
}, ref) {
  const theme = useGlobalTheme();
  const styles = useMemo(() => getCodeStyles(theme), [theme]);
  const {
    children,
    codeBidiWarnings = true,
    codeBidiWarningLabel,
    ...otherProps
  } = props;
  const decoratedChildren = codeBidiWarnings ? jsx(RenderCodeChildrenWithBidiWarnings, {
    codeBidiWarningLabel: codeBidiWarningLabel
  }, children) : children;
  return jsx("code", _extends({
    ref: ref,
    "data-testid": testId,
    css: styles
  }, otherProps), decoratedChildren);
}));

function RenderCodeChildrenWithBidiWarnings({
  children,
  codeBidiWarningLabel
}) {
  const replacedChildren = React.Children.map(children, childNode => {
    if (typeof childNode === 'string') {
      const decorated = codeBidiWarningDecorator(childNode, ({
        bidiCharacter,
        index
      }) => jsx(CodeBidiWarning, {
        bidiCharacter: bidiCharacter,
        key: index,
        label: codeBidiWarningLabel
      }));
      return decorated;
    }

    if (isReactElement(childNode) && childNode.props.children) {
      const newChildNode = /*#__PURE__*/React.cloneElement(childNode, {
        children: jsx(RenderCodeChildrenWithBidiWarnings, {
          codeBidiWarningLabel: codeBidiWarningLabel
        }, childNode.props.children)
      });
      return newChildNode;
    }

    return childNode;
  });
  return jsx(React.Fragment, null, replacedChildren);
}

function isReactElement(child) {
  return !!child.type;
}

Code.displayName = 'Code';
export { getCodeStyles };
export default Code;