import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

/** @jsx jsx */
import React, { forwardRef, memo, useMemo } from 'react';
import { jsx } from '@emotion/core';
import { useGlobalTheme } from '@atlaskit/theme/components';
import CodeBidiWarning from './bidi-warning';
import codeBidiWarningDecorator from './bidi-warning/bidi-warning-decorator';
import { getCodeStyles } from './internal/theme/styles';
var Code = /*#__PURE__*/memo( /*#__PURE__*/forwardRef(function Code(_ref, ref) {
  var testId = _ref.testId,
      props = _objectWithoutProperties(_ref, ["testId"]);

  var theme = useGlobalTheme();
  var styles = useMemo(function () {
    return getCodeStyles(theme);
  }, [theme]);

  var children = props.children,
      _props$codeBidiWarnin = props.codeBidiWarnings,
      codeBidiWarnings = _props$codeBidiWarnin === void 0 ? true : _props$codeBidiWarnin,
      codeBidiWarningLabel = props.codeBidiWarningLabel,
      otherProps = _objectWithoutProperties(props, ["children", "codeBidiWarnings", "codeBidiWarningLabel"]);

  var decoratedChildren = codeBidiWarnings ? jsx(RenderCodeChildrenWithBidiWarnings, {
    codeBidiWarningLabel: codeBidiWarningLabel
  }, children) : children;
  return jsx("code", _extends({
    ref: ref,
    "data-testid": testId,
    css: styles
  }, otherProps), decoratedChildren);
}));

function RenderCodeChildrenWithBidiWarnings(_ref2) {
  var children = _ref2.children,
      codeBidiWarningLabel = _ref2.codeBidiWarningLabel;
  var replacedChildren = React.Children.map(children, function (childNode) {
    if (typeof childNode === 'string') {
      var decorated = codeBidiWarningDecorator(childNode, function (_ref3) {
        var bidiCharacter = _ref3.bidiCharacter,
            index = _ref3.index;
        return jsx(CodeBidiWarning, {
          bidiCharacter: bidiCharacter,
          key: index,
          label: codeBidiWarningLabel
        });
      });
      return decorated;
    }

    if (isReactElement(childNode) && childNode.props.children) {
      var newChildNode = /*#__PURE__*/React.cloneElement(childNode, {
        children: jsx(RenderCodeChildrenWithBidiWarnings, {
          codeBidiWarningLabel: codeBidiWarningLabel
        }, childNode.props.children)
      });
      return newChildNode;
    }

    return childNode;
  });
  return jsx(React.Fragment, null, replacedChildren);
}

function isReactElement(child) {
  return !!child.type;
}

Code.displayName = 'Code';
export { getCodeStyles };
export default Code;